#! /bin/sh
#
#+
#
# .. program:: concat_eraiy.sh
#
# .. _concat_eraiy.sh:
#
# ===============
# concat_eraiy.sh 
# ===============
#
# SYNOPSIS
# ========
#
# ::
#
#  $ concat_eraiy.sh [--debug] -b yyyymmdd -e yyyymmdd
#
# DESCRIPTION
# ===========
#
# .. option:: --debug
#
#    If this option is set, :samp:`ncdump -v time` and :samp:`cdo showdate`
#    will be added to log file
#
# .. option:: -b beginning date <yyyymmdd>
# .. option:: -e end date <yyyymmdd>
#
# Concatane yearly ERA-I files located 
# in :file:`/net/adonis/usr/adonis/varclim/tropflux_v1/input`
# in ${PROJECT_ID}
#
# Log file is written on 
# :file:`${PROJECT_LOG}/concat_eraiy.log.{YYYYMMDDTHHMMSSZ}`
#
#     .. graphviz::
#
#        digraph concat_eraiy {
#
#           filein_d2m [shape=ellipse,fontname=Courier,label="cratos:/net/adonis/usr/adonis/varclim/tropflux_v1/input/erai_d2m_yyyy.nc"];
#           filein_lwr [shape=ellipse,fontname=Courier,label="cratos:/net/adonis/usr/adonis/varclim/tropflux_v1/input/erai_lwr_yyyy.nc"];
#           filein_msl [shape=ellipse,fontname=Courier,label="cratos:/net/adonis/usr/adonis/varclim/tropflux_v1/input/erai_msl_yyyy.nc"];
#           filein_sst [shape=ellipse,fontname=Courier,label="cratos:/net/adonis/usr/adonis/varclim/tropflux_v1/input/erai_sst_yyyy.nc"];
#           filein_t2m [shape=ellipse,fontname=Courier,label="cratos:/net/adonis/usr/adonis/varclim/tropflux_v1/input/erai_t2m_yyyy.nc"];
#           filein_u10 [shape=ellipse,fontname=Courier,label="cratos:/net/adonis/usr/adonis/varclim/tropflux_v1/input/erai_u10_yyyy.nc"];
#           filein_v10 [shape=ellipse,fontname=Courier,label="cratos:/net/adonis/usr/adonis/varclim/tropflux_v1/input/erai_v10_yyyy.nc"];
#
#           fileout_d2m [shape=ellipse,fontname=Courier,label="${PROJECT_ID}/erai_d2m_yyyyb_yyyye.nc"];
#           fileout_lwr [shape=ellipse,fontname=Courier,label="${PROJECT_ID}/erai_lwr_yyyyb_yyyye.nc"];
#           fileout_msl [shape=ellipse,fontname=Courier,label="${PROJECT_ID}/erai_msl_yyyyb_yyyye.nc"];
#           fileout_sst [shape=ellipse,fontname=Courier,label="${PROJECT_ID}/erai_sst_yyyyb_yyyye.nc"];
#           fileout_t2m [shape=ellipse,fontname=Courier,label="${PROJECT_ID}/erai_t2m_yyyyb_yyyye.nc"];
#           fileout_u10 [shape=ellipse,fontname=Courier,label="${PROJECT_ID}/erai_u10_yyyyb_yyyye.nc"];
#           fileout_v10 [shape=ellipse,fontname=Courier,label="${PROJECT_ID}/erai_v10_yyyyb_yyyye.nc"];
#
#           concat_eraiy [shape=box,
#           fontname=Courier,
#           color=blue,
#           URL="http://forge.ipsl.jussieu.fr/tropflux/browser/trunk/src/concat_eraiy.sh",
#           label="${PROJECT}/src/concat_eraiy.sh"];
#
#           {filein_d2m filein_lwr filein_msl filein_sst filein_t2m filein_u10 filein_v10} -> {concat_eraiy} -> {fileout_d2m fileout_lwr fileout_sst fileout_t2m fileout_u10 fileout_v10}
#
#       }
#
# .. caution::
#
#    Output files if exist are overwritten.
#
# EXAMPLES
# ========
#
# On cratos only if you don't have any ERA-I data,
# you just have to run this tool ::
#
#  $ concat_eraiy.sh -b 19890102 -e 20091231
#
# And look at log file with ::
#
#  $ tlogd.sh concat_eraiy
#
# and of course on files in ${PROJECT_ID}.
#
# SEE ALSO
# ========
#
# :ref:`data_in_erai`
#
# :ref:`project_profile.sh`
#
# Used by :ref:`tropflux.sh`
#
# :func:`ncrcat <nco:ncrcat>`
#
# :func:`showdate <cdo:showdate>`
#
# :func:`interp_erai_dewt`
# :func:`interp_erai_lwr`
# :func:`interp_erai_sst`
# :func:`interp_erai_t2m`
# :func:`interp_erai_ws`
#
# TODO
# ====
#
# pour l'instant  cause de ::
#
#   has attribute "missing_value" but not "_FillValue"
#
# ncrcat renvoie systmatiquement un status diffrent de 0 mais il produit
# des fichiers
#
# donc j'ai pour l'instant court-circuter la sortie en erreur
# tant que je n'ai pas renomm missing_value ou ajouter _FillValue
#
# changement des attributs globaux dans fichiers de sortie
#
# catalog
#
# improve log 
#
# handle dd parameter : now from 1 to end of month
#
# adjust yyyymmddb_min and yyyymmddb_max
#
# trouble with cdo reference (extra %23name in generated url using sphinx1.0.7)
#
# coding rules
#
# work elsewhere cratos
#
# enrich info in log file
#
# EVOLUTIONS
# ==========
#
# $Id$
#
# $URL$
#
# - fplod 20120704T104404Z cratos (Linux)
#
#   * creation for new era-i dataset
#
#-
system=$(uname)
case "${system}" in
   AIX|IRIX64)
      echo "www : no specific posix checking"
      date_cmd=date
   ;;
   Darwin)
      set -o posix
      date_cmd=gdate
   ;;
   Linux)
      set -o posix
      date_cmd=date
   ;;
   *)
     set -o posix
   ;;
esac
unset system
#
LANG=POSIX
#
set -u
#
command=$(basename ${0})
log_date=$(date -u +"%Y%m%dT%H%M%SZ")
#
usage=" Usage : ${command} [--debug] -b yyyymmdd -e yyyymmdd"
#
hostname=$(hostname)
#
yyyymmddb_min=19790101
yyyymmdde_max=20110930
#
# default
debug=0
yyyymmddb=19790101
yyyymmdde=20110930
#
minargcount=4
if [ ${#} -lt ${minargcount} ]
then
   echo "${command} : eee : not enought arguments"
   echo "${usage}"
   exit 1
fi
#
while [ ${#} -gt 0 ]
do
   case ${1} in
      --debug)
         debug=1
      ;;
      -b)
         # first date to get
         yyyymmddb=${2}
         shift
      ;;
      -e)
         # last date to get
         yyyymmdde=${2}
         shift
      ;;
      *)
        # anything else
        echo "${command} : eee : unknown option ${1}"
        echo "${command} : eee : ${usage}"
        exit 1
      ;;
   esac
   # next flag
   shift
done
#
# check parameters
#
${date_cmd} -d "${yyyymmddb}" > /dev/null
status_date=${?}
if [ ${status_date} -ne 0 ]
then
     echo "${command} : eee : yyyymmddb ${yyyymmddb} argument invalid"
     exit 1
fi
unset status_date
#
if [[ "${yyyymmddb}" < "${yyyymmddb_min}" ]]
then
     echo "${command} : eee : yyyymmddb ${yyyymmddb} must be equal or greater than ${yyyymmddb_min}"
     exit 1
fi
#
${date_cmd} -d "${yyyymmdde}" > /dev/null
status_date=${?}
if [ ${status_date} -ne 0 ]
then
     echo "${command} : eee : yyyymmdde ${yyyymmdde} argument invalid"
     exit 1
fi
unset status_date
#
if [[ "${yyyymmdde}" > "${yyyymmdde_max}" ]]
then
     echo "${command} : eee : yyyymmdde ${yyyymmdde} must be lower or equal to ${yyyymmdde_max}"
     exit 1
fi
#
#
if [[ "${yyyymmdde}" < "${yyyymmddb}" ]]
then
     echo "${command} : eee : yyyymmdde ${yyyymmdde} must be equal or greater than yyyymmddb ${yyyymmddb}"
     exit 1
fi
# 
# test if cdo available
tool=cdo
type ${tool} 1> /dev/null 2>&1
status=${?}
if [ ${status} -ne 0 ]
then
   echo "${command} : eee : ${tool} not found"
   exit 1
fi
unset status

# check for ${PROJECT_LOG} definition
if [ "${PROJECT_LOG}" = "" ]
then
   echo "${command} : eee : \${PROJECT_LOG} not defined"
   exit 1
fi
#
# check for ${PROJECT_LOG} existence
if [ ! -d ${PROJECT_LOG} ]
then
   echo "${command} : eee : ${PROJECT_LOG} not found"
   exit 1
fi
#
# check for permission access on PROJECT_LOG
if [ ! -x ${PROJECT_LOG} ]
then
   echo "${command} : eee : ${PROJECT_LOG} not reachable"
   exit 1
fi
#
# check for write permission on PROJECT_LOG
if [ ! -w ${PROJECT_LOG} ]
then
   echo "${command} : eee : ${PROJECT_LOG} not writable"
   exit 1
fi
#
dirtemp=${PROJECT_LOG}/$(basename ${0} .sh).${log_date}.temp/
mkdir -p ${dirtemp}
#
log=${PROJECT_LOG}/$(basename ${0} .sh).log.${log_date}
echo "[Context]" 1>> ${log}
echo "command=$(basename ${0})" 1>>${log}
echo "hostname=${hostname}" 1>> ${log}
echo "runtime=${log_date}" 1>> ${log}
echo "log=${log}" 1>> ${log}
unset log_date
#
echo "" 1>> ${log}
echo "[Parameters]" 1>> ${log}
echo "yyyymmddb=${yyyymmddb}" 1>> ${log}
echo "yyyymmdde=${yyyymmdde}" 1>> ${log}
echo "" 1>> ${log}
#
yyyymin=$(${date_cmd} -d "${yyyymmddb}" +%Y)
yyyymax=$(${date_cmd} -d "${yyyymmdde}" +%Y)
dirin=/net/adonis/usr/adonis/varclim/tropflux_v1/input
# check for dirin existence
if [ ! -d ${dirin} ]
then
   echo "${command} : eee : ${dirin} not found"
   exit 1
fi
#
# check for permission access on dirin
if [ ! -x ${dirin} ]
then
   echo "${command} : eee : ${dirin} not reachable"
   exit 1
fi
#
list_var="d2m lwr msl sst t2m u10 v10"
for var in ${list_var}
do
   fileout=${PROJECT_ID}/erai_${var}_${yyyymin}_${yyyymax}.nc
   if [ ${yyyymin} -eq ${yyyymax} ]
   then
      list_filein=${dirin}/erai_${var}_${yyyymin}.nc
      cp ${list_filein} ${fileout} 1>> ${log} 2>&1
   else
      list_filein=$(seq -f "${dirin}/erai_${var}_%g.nc" ${yyyymin} ${yyyymax})
      # concatenation of files
      ncrcat -O -o ${fileout} ${list_filein} 1>> ${log} 2>&1
      status_ncrcat=${?}
      if [ ${status_ncrcat} -ne 0 ]
      then
           echo "${command} : www : pb with ncrcat : ${status_ncrcat} " 2>> ${log}
           #++exit 1
      else
           echo "${command} : iii : ncrcat ok " 1>> ${log}
           echo "${command} : iii : see ${fileout} " 1>> ${log}
      fi
      unset status_ncrcat
   fi
   if [ ${debug} -eq 1 ]
   then
       ncdump -v time ${fileout} >> ${log} 2>&1
       cdo showdate ${fileout} >> ${log} 2>&1
   fi
   unset list_filein
   unset fileout
done
unset var
unset list_var
# end
exit 0
