#!/usr/bin/env python
# -*- coding: iso-8859-1 -*-

__docformat__ = "restructuredtext en"
__version__ = '$Id$'

"""

DESCRIPTION
===========

get ERA-Interim reference files between two dates

SYNOPSIS
========

::

 $ get_erai.py --begin yyyymmdd --end yyyymmdd

EXAMPLES
========

::

 $ get_erai.py --verbose --begin 20010101 --end 20010330

SEE ALSO
========

:ref:`ecmwf`

for interactif retrieval
http://data-portal.ecmwf.int/data/d/interim_daily/

http://data-portal.ecmwf.int/data/d/interim_full_daily

For python script syntax
http://data-portal.ecmwf.int/data/d/token/interim_daily/

"Please note that these batch scripts are available for download in grib format only. " ...

MARS language
http://www.ecmwf.int/publications/manuals/mars/guide/index.html

TIPS
====

To convet a GRIB file to a NetCDF file ::

  $ cdo -f nc copy data.grib data.nc

TODO
====

make it work for all needed variables

produce netcdf files : now grib dispite name of the file target

comment

nb : le champ str (wind stress pourra/devra tre rcupr pour faire des comparaisons (cf. 20c3m_erai_str_TROP_1989_2009.nc)

nb :Mean sea level pressure en a-t-on vraiment besoin ? jusqu' prsent on ne sait pas si pkb l'a utilis.

EVOLUTIONS
==========

$Id$

$URL$

- fplod 20120314

  * add parameters

- fplod 20120306

  * add all param for analyse (it might be better to do a loop to produce
    one file/field
  * add retrieve for forecast (only one parameter here)

- fplod 20111130T153500Z cratos (Linux)

  * got from http://data-portal.ecmwf.int/data/d/token/interim_full_daily/
  * add docstring

"""

import os
from optparse import OptionParser
import time
import datetime
from dateutil.parser import *

from ecmwf import ECMWFDataServer

def get_option_parser ():
    """parse CLI arguments

    :returns: parser
    :rtype: :class:`optparse.OptionParser`
    """

    parser = OptionParser('%prog [--verbose] --begin yyyymmdd --end yyymmdd ')

    parser = OptionParser(conflict_handler="resolve")

    parser.add_option ('-V', '--verbose', help='produce verbose output',
          action='store_true',
          default=False,
          dest='is_verbose')

    parser.add_option('--version',
         action='store_true',
         dest='version',
         help='show version number and exit')

    parser.add_option('--begin',
           help='date (yyyymmdd) of the first date',
           dest='yyyymmddb',
           action='store')

    parser.add_option('--end',
           help='date (yyyymmdd) of the last date',
           dest='yyyymmdde',
           action='store')

    return parser

def get_erai():
    """main
    """
    try:
       parser = get_option_parser ()
       (fromcli, args) = parser.parse_args()
    except IOError, msg:
       parser.error(str(msg))

    yyyymmddb = parse(fromcli.yyyymmddb, ignoretz=True)
    yyyymmdde = parse(fromcli.yyyymmdde, ignoretz=True)

    # ++ check date validity and interval validity
    if fromcli.is_verbose == True:
       print ('yyyymmddb %s' % (yyyymmddb))
       print ('yyyymmdde %s' % (yyyymmdde))

    # build the value of date parameter yyyymmdd/to/yyyymmdd
    date_param = fromcli.yyyymmddb + '/to/' + fromcli.yyyymmdde

    if fromcli.is_verbose == True:
       print ('date for erai %s' % (date_param))

    server = ECMWFDataServer(
           'http://data-portal.ecmwf.int/data/d/dataserver/',
                  'd558d095ce964389eeda5e908e9462f3',
                 'Francoise.Pinsard@locean-ipsl.upmc.fr'
             )

    # Pour les analyses de
    #        10 metre U wind component
    #        10 metre V wind component
    #        2 metre temperature
    #        2 metre dewpoint temperature
    #        Sea surface temperature
    #        Mean sea level pressure
    param_param = []
    param_param.append("34.128") #Sea surface temperature sstk
    #param_param.append("151.128") Mean sea level pressure
    #param_param.append("165.128") 10 metre U wind component u10
    #param_param.append("166.128") 10 metre V wind component v10
    #param_param.append("167.128") 2 metre temperature t2
    #param_param.append("168.128") 2 metre dewpoint temperature d2

    for one_param in param_param:

        if fromcli.is_verbose == True:
            print('recup de %s ' %  one_param)

        server.retrieve({
            'dataset' : "interim_full_daily",
            'date'    : date_param,
            'time'    : "00:00:00/06:00:00/12:00:00/18:00:00",
            'grid'    : "1/1",
            'step'    : "0",
            'levtype' : "sfc",
            'type'    : "an",
            'param'   : one_param,
            'area'    : "60/-120/30/-60",
            'target'  : "toto.grib"
            })

    # Pour la "Surface thermal radiation downwards":
    param_param = []
    param_param.append("175.128")  # Surface thermal radiation downwards
    for one_param in param_param:

       if fromcli.is_verbose == True:
           print('recup de %s'  % one_param)

       server.retrieve({
           'dataset' : "interim_full_daily",
           'date'    : date_param,
           'time'    : "00:00:00/12:00:00",
           'grid'    : "1/1",
           'step'    : "12",
           'levtype' : "sfc",
           'type'    : "fc",
           'param'   : param_param,
           'area'    : "60/-120/30/-60",
           'target'  : "fc.grib"
             })

# Run main, if called from the command line
if __name__ == '__main__':
   get_erai()

