;+
; .. _fig10_swr_correction.pro:
;
; ========================
; fig10_swr_correction.pro
; ========================
;
; DESCRIPTION
; ===========
;
; .. graphviz::
;
;    digraph fig10_swr_correction {
;
;       swr_isccp [shape=ellipse,fontname=Courier,label="${PROJECT_ID}/swr_isccp_correction.txt"];
;
;       figure [shape=ellipse,fontname=Courier,label="${PROJECT_OD}/fig10_swr_correction.ps"];
;
;       fig10_swr_correction [shape=box,
;       fontname=Courier,
;       color=blue,
;       URL="http://forge.ipsl.jussieu.fr/tropflux/broswrer/trunk/src/paper01/fig10/fig10_swr_correction.pro",
;       label="${TROPFLUX}/src/paper01/fig10/fig10_swr_correction.pro"];
;
;       {swr_isccp} -> {fig10_swr_correction} -> {figure}
;    }
;
; SEE ALSO
; ========
;
; :ref:`project_profile.sh`
; :ref:`project_init.pro`
; :ref:`cm_project.pro`
;
; :ref:`significance_test_99.pro`
;
; EXAMPLES
; ========
;
; ::
;
;  @project_init
;  fig10_swr_correction
;
; TODO
; ====
;
; check results
;
; improve plot
;
; coding rules
;
; complete description
;
; handle IO error
;
; EVOLUTIONS
; ==========
;
; $Id$
;
; $URL$
;
; - fplod 20110420T140853Z aedon.locean-ipsl.upmc.fr (Darwin)
;
;   * make it work on cratos
;   * replace significance_test by significance_test_99
;
; - fplod 20110420T105744Z aedon.locean-ipsl.upmc.fr (Darwin)
;
;   * remove hard coding path
;   * add graphviz
;
; - fplod 20110411T142955Z aedon.locean-ipsl.upmc.fr (Darwin)
;
;   * minimal header
;
;-
pro fig10_swr_correction
@cm_general
@cm_project
reinitplt, /z,/invert
key_portrait = 1
;
openps, FILENAME = project_od_env+'fig10_swr_correction.ps'
close,/all
;
fi=project_id_env+'swr_isccp_correction.txt'
res=read_ascii(fi,data_start=0)
ff=res.field1
cor=reform(ff(0,*))
bias=reform(ff(1,*))
std=reform(ff(2,*))
mean=reform(ff(4,*))
;
splot, mean, bias, small=[2,3,1], xtitle='Mean ERA-I SWR', ytitle='ERA-I SWR bias', $
       title='', psym=2, charsize=1.2,  $
       xrange=[170,290], yrange=[-10,35], xmin=1, ymin=1
;
ab=linfit(mean, bias,yfit=yfit)
a=float(ab(0))
b=float(ab(1))
oplot, mean, yfit, thick=3
print, a,b
; significant test
significance_test_99,mean,bias
;
fi=project_id_env+'swr_isccp_correction.txt'
res=read_ascii(fi,data_start=0)
ff=res.field1
cor=reform(ff(0,*))
bias=reform(ff(1,*))
std=reform(ff(2,*))
mean=reform(ff(4,*))
;
splot, mean, std, small=[2,3,3],/noer, xtitle='Mean ERA-I SWR', ytitle='ERA-I std ratio', $
       title='', psym=2, charsize=1.2,  $
       xrange=[170,290], yrange=[0.4,1.4], xmin=1, ymin=1
;
ab=linfit(mean, std,yfit=yfit)
a=float(ab(0))
b=float(ab(1))
oplot, mean, yfit, thick=3
;
; significant test
significance_test_99,mean,std
;
closeps
;
end
