;+
; .. _swr_statistics_map_2000_2009_v50.pro:
;
; ====================================
; swr_statistics_map_2000_2009_v50.pro
; ====================================
;
; DESCRIPTION
; ===========
;
; .. graphviz::
;
;    digraph swr_statistics_map_2000_2009_v50 {
;
;       swr_erai [shape=ellipse,fontname=Courier,label="${PROJECT_ID}/swr_2000_2009_erai_v50.txt"];
;       swr_trop [shape=ellipse,fontname=Courier,label="${PROJECT_ID}/swr_2000_2009_trop_v50.txt"];
;       swr_oaflx [shape=ellipse,fontname=Courier,label="${PROJECT_ID}/swr_2000_2009_oaflx_v50.txt"];
;       swr_olr [shape=ellipse,fontname=Courier,label="${PROJECT_ID}/swr_2000_2009_olr_v50.txt"];
;       mask [shape=ellipse,fontname=Courier,label="${PROJECT_ID}/longwave_IO_mask.nc"];
;
;       figure [shape=ellipse,fontname=Courier,label="${PROJECT_OD}/swr_statistics_map_2000_2009_v50.ps"];
;
;       swr_statistics_map_2000_2009_v50 [shape=box,
;       fontname=Courier,
;       color=blue,
;       URL="http://forge.ipsl.jussieu.fr/tropflux/broswrer/trunk/src/paper01/fig12/swr_statistics_map_2000_2009_v50.pro",
;       label="${TROPFLUX}/src/paper01/fig12/swr_statistics_map_2000_2009_v50.pro"];
;
;       {swr_erai swr_trop swr_oaflx swr_olr mask} -> {swr_statistics_map_2000_2009_v50} -> {figure}
;    }
;
; SEE ALSO
; ========
;
; :ref:`project_profile.sh`
; :ref:`project_init.pro`
; :ref:`cm_project.pro`
;
; EXAMPLES
; ========
;
; ::
;
;  swr_statistics_map_2000_2009_v50
;
; TODO
; ====
;
; make it work on cratos : missing data
;
; coding rules
;
; complete description
;
; handle IO error
;
; EVOLUTIONS
; ==========
;
; $Id$
;
; $URL$
;
; - fplod 20110420T113846Z aedon.locean-ipsl.upmc.fr (Darwin)
;
;   * remove stop
;   * remove hard coding path
;   * add graphviz
;
; - fplod 20110411T142955Z aedon.locean-ipsl.upmc.fr (Darwin)
;
;   * minimal header
;
;-
pro swr_statistics_map_2000_2009_v50
@cm_general
@cm_project
reinitplt, /z,/invert
key_portrait = 1
coefpalit=.9
;
openps, FILENAME = project_od_env+'swr_statistics_map_2000_2009_v50.ps'
; partie a changer
bias_mi=-20
bias_ma=20
bias_int=2
std_mi=0.7
std_ma=1.31
std_int=0.05
rmsd_mi=10
rmsd_ma=30
rmsd_int=1.25
cor_mi=0.5
cor_ma=1.
cor_int=0.02
fi_swr_erai=project_id_env+'swr_2000_2009_erai_v50.txt'
fi_swr_trop=project_id_env+'swr_2000_2009_trop_v50.txt'
fi_swr_oaflx=project_id_env+'swr_2000_2009_oaflx_v50.txt'
fi_swr_olr=project_id_env+'swr_2000_2009_olr_v50.txt'
;
res=read_ascii(fi_swr_erai,data_start=1)
ff=res.field1
lat=reform(ff(0,*))
lon=reform(ff(1,*))
cor_era=reform(ff(2,*))
bias_era=reform(ff(3,*))
std_era=reform(ff(4,*))
rmsd_era=reform(ff(5,*))
;
ind=where(bias_era ge bias_ma)
bias_era(ind)=bias_ma-0.5
ind=where(rmsd_era ge rmsd_ma)
rmsd_era(ind)=rmsd_ma-0.5
;
res=read_ascii(fi_swr_trop,data_start=1)
ff=res.field1
lat=reform(ff(0,*))
lon=reform(ff(1,*))
cor_trop=reform(ff(2,*))
bias_trop=reform(ff(3,*))
std_trop=reform(ff(4,*))
rmsd_trop=reform(ff(5,*))
ind=where(rmsd_trop ge rmsd_ma)
rmsd_trop(ind)=rmsd_ma-0.5
;
res=read_ascii(fi_swr_oaflx,data_start=1)
ff=res.field1
lat=reform(ff(0,*))
lon=reform(ff(1,*))
cor_oaflx=reform(ff(2,*))
bias_oaflx=reform(ff(3,*))
std_oaflx=reform(ff(4,*))
rmsd_oaflx=reform(ff(5,*))
ind=where(rmsd_oaflx ge rmsd_ma)
rmsd_oaflx(ind)=rmsd_ma-0.5
;
res=read_ascii(fi_swr_olr,data_start=1)
ff=res.field1
lat=reform(ff(0,*))
lon=reform(ff(1,*))
cor_olr=reform(ff(2,*))
bias_olr=reform(ff(3,*))
std_olr=reform(ff(4,*))
rmsd_olr=reform(ff(5,*))
ind=where(rmsd_olr ge rmsd_ma)
rmsd_olr(ind)=rmsd_ma-0.5
;
;ind=where(std_olr ge std_ma)
;std_olr(ind)=std_ma-0.01
file=project_id_env+'longwave_IO_mask.nc'
initncdf, file
domdef, 30,390,-30,30
msk=ncdf_lec(file,var='msk')
;box=[0,290,-30,30]
marge=[0,0,-0.8,0]
marge1=[0,0,-5,0]
plt, .4+msk*1.e-5,realcont=2,/nocont,/nofill,xminor=1,yminor=1,box=box,lct=64,cor_mi, cor_ma,int=cor_int, $
   title='1) SWR Correlation - TropFlux', subtitle='', small=[1,4,1],/rempl,/nocolorb, marge=marge
;
NN=n_elements(lat)
;
usersym, [-.5,.5,.5,-.5,-.5],[-.5,-.5,.5,.5,-.5],/fill
;
for n=0,NN-1 do begin
  x=lon(n)
  y=lat(n)
  c=cor_trop(n)
  cmi=cor_mi
  cma=cor_ma
  dc=cma-cmi
  col=((10+244*(c-cmi)/dc) > 10) < 254
  plots, x,y,psym=8,symsize=1.5,color=col
endfor
;
usersym, [-.5,.5,.5,-.5,-.5],[-.5,-.5,.5,.5,-.5]
;
for n=0,NN-1 do begin
  x=lon(n)
  y=lat(n)
  c=cor_trop(n)
;
  plots, x,y,psym=8,symsize=1.5,color=0
endfor
plt, 12+msk,realcont=2,/nocont,/nofill,xminor=1,yminor=1,lct=64,cor_mi, cor_ma,int=cor_int,/nocolorb, $
   title='2) SWR Correlation -  ERAI', subtitle='', small=[1,4,2],/noer,/rempl, marge=marge
;
NN=n_elements(lat)
;
usersym, [-.5,.5,.5,-.5,-.5],[-.5,-.5,.5,.5,-.5],/fill
;
for n=0,NN-1 do begin
  x=lon(n)
  y=lat(n)
  c=cor_era(n)
  cmi=cor_mi
  cma=cor_ma
  dc=cma-cmi
  col=((10+244*(c-cmi)/dc) > 10) < 254
  plots, x,y,psym=8,symsize=1.5,color=col
endfor
;
usersym, [-.5,.5,.5,-.5,-.5],[-.5,-.5,.5,.5,-.5]
;
for n=0,NN-1 do begin
  x=lon(n)
  y=lat(n)
  c=cor_era(n)
;
  plots, x,y,psym=8,symsize=1.5,color=0
endfor
plt, 12+msk,realcont=2,/nocont,/nofill,xminor=1,yminor=1,lct=64,cor_mi, cor_ma,int=cor_int,/nocolorb, $
   title='3) SWR Correlation - OAFlux', subtitle='', small=[1,4,3],/noer,/rempl, marge=marge
;
NN=n_elements(lat)
;
usersym, [-.5,.5,.5,-.5,-.5],[-.5,-.5,.5,.5,-.5],/fill
;
for n=0,NN-1 do begin
  x=lon(n)
  y=lat(n)
  c=cor_oaflx(n)
  cmi=cor_mi
  cma=cor_ma
  dc=cma-cmi
  col=((10+244*(c-cmi)/dc) > 10) < 254
  plots, x,y,psym=8,symsize=1.5,color=col
endfor
;
usersym, [-.5,.5,.5,-.5,-.5],[-.5,-.5,.5,.5,-.5]
;
for n=0,NN-1 do begin
  x=lon(n)
  y=lat(n)
  c=cor_oaflx(n)
;
  plots, x,y,psym=8,symsize=1.5,color=0
endfor
plt, 12+msk,realcont=2,/nocont,/nofill,xminor=1,yminor=1,lct=64,cor_mi, cor_ma,int=cor_int, $
   title='4) SWR Correlation - SWR_olr', subtitle='', small=[1,4,4],/noer,/rempl, marge=marge1
;
NN=n_elements(lat)
;
usersym, [-.5,.5,.5,-.5,-.5],[-.5,-.5,.5,.5,-.5],/fill
;
for n=0,NN-1 do begin
  x=lon(n)
  y=lat(n)
  c=cor_olr(n)
  cmi=cor_mi
  cma=cor_ma
  dc=cma-cmi
  col=((10+244*(c-cmi)/dc) > 10) < 254
  plots, x,y,psym=8,symsize=1.5,color=col
endfor
;
usersym, [-.5,.5,.5,-.5,-.5],[-.5,-.5,.5,.5,-.5]
;
for n=0,NN-1 do begin
  x=lon(n)
  y=lat(n)
  c=cor_olr(n)
;
  plots, x,y,psym=8,symsize=1.5,color=0
endfor
;
erase
;
plt, -5+msk*1.e-5,realcont=2,/nocont,/nofill,xminor=1,yminor=1,lct=64,bias_mi, bias_ma, int=bias_int, marge=marge,/nocolorb, $
   title='1) SWR Mean bias - TropFlux', subtitle='', small=[1,4,1],/rempl,format='(i3)'
;
NN=n_elements(lat)
;
usersym, [-.5,.5,.5,-.5,-.5],[-.5,-.5,.5,.5,-.5],/fill
;
for n=0,NN-1 do begin
  x=lon(n)
  y=lat(n)
  c=bias_trop(n)
  cmi=bias_mi
  cma=bias_ma
  dc=cma-cmi
  col=((10+244*(c-cmi)/dc) > 10) < 254
  plots, x,y,psym=8,symsize=1.5,color=col
endfor
;
usersym, [-.5,.5,.5,-.5,-.5],[-.5,-.5,.5,.5,-.5]
;
for n=0,NN-1 do begin
  x=lon(n)
  y=lat(n)
  c=bias_trop(n)
;
  plots, x,y,psym=8,symsize=1.5,color=0
endfor
plt,0.8+msk*1.e-5,realcont=2,/nocont,/nofill,xminor=1,yminor=1,lct=64,bias_mi, bias_ma, int=bias_int,/noer, marge=marge, $
   title='2) SWR Mean bias - ERAI', subtitle='', small=[1,4,2],/rempl,format='(i3)',/nocolorb
;
NN=n_elements(lat)
;
usersym, [-.5,.5,.5,-.5,-.5],[-.5,-.5,.5,.5,-.5],/fill
;
for n=0,NN-1 do begin
  x=lon(n)
  y=lat(n)
  c=bias_era(n)
  cmi=bias_mi
  cma=bias_ma
  dc=cma-cmi
  col=((10+244*(c-cmi)/dc) > 10) < 254
  plots, x,y,psym=8,symsize=1.5,color=col
endfor
;
usersym, [-.5,.5,.5,-.5,-.5],[-.5,-.5,.5,.5,-.5]
;
for n=0,NN-1 do begin
  x=lon(n)
  y=lat(n)
  c=bias_era(n)
;
  plots, x,y,psym=8,symsize=1.5,color=0
endfor
;
plt,0.8+msk*1.e-5,realcont=2,/nocont,/nofill,xminor=1,yminor=1,lct=64,bias_mi, bias_ma, int=bias_int,/noer, marge=marge, $
   title='3) SWR Mean bias - OAFlux', subtitle='', small=[1,4,3],/rempl,format='(i3)',/nocolorb
;
NN=n_elements(lat)
;
usersym, [-.5,.5,.5,-.5,-.5],[-.5,-.5,.5,.5,-.5],/fill
;
for n=0,NN-1 do begin
  x=lon(n)
  y=lat(n)
  c=bias_oaflx(n)
  cmi=bias_mi
  cma=bias_ma
  dc=cma-cmi
  col=((10+244*(c-cmi)/dc) > 10) < 254
  plots, x,y,psym=8,symsize=1.5,color=col
endfor
;
usersym, [-.5,.5,.5,-.5,-.5],[-.5,-.5,.5,.5,-.5]
;
for n=0,NN-1 do begin
  x=lon(n)
  y=lat(n)
  c=bias_oaflx(n)
;
  plots, x,y,psym=8,symsize=1.5,color=0
endfor
;
plt,0.8+msk*1.e-5,realcont=2,/nocont,/nofill,xminor=1,yminor=1,lct=64,bias_mi, bias_ma, int=bias_int,/noer, marge=marge1, $
   title='4) SWR Mean bias - SWR_olr', subtitle='', small=[1,4,4],/rempl ;,format='(i4)'
;
NN=n_elements(lat)
;
usersym, [-.5,.5,.5,-.5,-.5],[-.5,-.5,.5,.5,-.5],/fill
;
for n=0,NN-1 do begin
  x=lon(n)
  y=lat(n)
  c=bias_olr(n)
  cmi=bias_mi
  cma=bias_ma
  dc=cma-cmi
  col=((10+244*(c-cmi)/dc) > 10) < 254
  plots, x,y,psym=8,symsize=1.5,color=col
endfor
;
usersym, [-.5,.5,.5,-.5,-.5],[-.5,-.5,.5,.5,-.5]
;
for n=0,NN-1 do begin
  x=lon(n)
  y=lat(n)
  c=bias_olr(n)
;
  plots, x,y,psym=8,symsize=1.5,color=0
endfor
;
erase
;
plt,0.8+msk*1.e-5,realcont=2,/nocont,/nofill,xminor=1,yminor=1,lct=64,rmsd_mi, rmsd_ma, int=rmsd_int,/noer, $
   title='1) RMSD - TropFlux', subtitle='', small=[1,4,1],/rempl,/nocolorb, marge=marge
;
NN=n_elements(lat)
;
usersym, [-.5,.5,.5,-.5,-.5],[-.5,-.5,.5,.5,-.5],/fill
;
for n=0,NN-1 do begin
  x=lon(n)
  y=lat(n)
  c=rmsd_trop(n)
  cmi=rmsd_mi
  cma=rmsd_ma
  dc=cma-cmi
  col=((10+244*(c-cmi)/dc) > 10) < 254
  plots, x,y,psym=8,symsize=1.5,color=col
endfor
;
usersym, [-.5,.5,.5,-.5,-.5],[-.5,-.5,.5,.5,-.5]
;
for n=0,NN-1 do begin
  x=lon(n)
  y=lat(n)
  c=rmsd_trop(n)
;
  plots, x,y,psym=8,symsize=1.5,color=0
endfor
plt,0.8+msk*1.e-5,realcont=2,/nocont,/nofill,xminor=1,yminor=1,lct=64,rmsd_mi, rmsd_ma, int=rmsd_int,/noer, $
   title='2) RMSD - ERAI', subtitle='', small=[1,4,2],/rempl,/nocolorb, marge=marge
;
NN=n_elements(lat)
;
usersym, [-.5,.5,.5,-.5,-.5],[-.5,-.5,.5,.5,-.5],/fill
;
for n=0,NN-1 do begin
  x=lon(n)
  y=lat(n)
  c=rmsd_era(n)
  cmi=rmsd_mi
  cma=rmsd_ma
  dc=cma-cmi
  col=((10+244*(c-cmi)/dc) > 10) < 254
  plots, x,y,psym=8,symsize=1.5,color=col
endfor
;
usersym, [-.5,.5,.5,-.5,-.5],[-.5,-.5,.5,.5,-.5]
;
for n=0,NN-1 do begin
  x=lon(n)
  y=lat(n)
  c=rmsd_era(n)
;
  plots, x,y,psym=8,symsize=1.5,color=0
endfor
plt,0.8+msk*1.e-5,realcont=2,/nocont,/nofill,xminor=1,yminor=1,lct=64,rmsd_mi, rmsd_ma, int=rmsd_int,/noer, $
   title='3) RMSD - OAFlux', subtitle='', small=[1,4,3],/rempl,/nocolorb, marge=marge
;
NN=n_elements(lat)
;
usersym, [-.5,.5,.5,-.5,-.5],[-.5,-.5,.5,.5,-.5],/fill
;
for n=0,NN-1 do begin
  x=lon(n)
  y=lat(n)
  c=rmsd_oaflx(n)
  cmi=rmsd_mi
  cma=rmsd_ma
  dc=cma-cmi
  col=((10+244*(c-cmi)/dc) > 10) < 254
  plots, x,y,psym=8,symsize=1.5,color=col
endfor
;
usersym, [-.5,.5,.5,-.5,-.5],[-.5,-.5,.5,.5,-.5]
;
for n=0,NN-1 do begin
  x=lon(n)
  y=lat(n)
  c=rmsd_oaflx(n)
;
  plots, x,y,psym=8,symsize=1.5,color=0
endfor
;
plt,0.8+msk*1.e-5,realcont=2,/nocont,/nofill,xminor=1,yminor=1,lct=64,rmsd_mi, rmsd_ma, int=rmsd_int,/noer, $
   title='4) RMSD - SWR_olr', subtitle='', small=[1,4,4],/rempl, marge=marge1
;
NN=n_elements(lat)
;
usersym, [-.5,.5,.5,-.5,-.5],[-.5,-.5,.5,.5,-.5],/fill
;
for n=0,NN-1 do begin
  x=lon(n)
  y=lat(n)
  c=rmsd_olr(n)
  cmi=rmsd_mi
  cma=rmsd_ma
  dc=cma-cmi
  col=((10+244*(c-cmi)/dc) > 10) < 254
  plots, x,y,psym=8,symsize=1.5,color=col
endfor
;
usersym, [-.5,.5,.5,-.5,-.5],[-.5,-.5,.5,.5,-.5]
;
for n=0,NN-1 do begin
  x=lon(n)
  y=lat(n)
  c=rmsd_olr(n)
;
  plots, x,y,psym=8,symsize=1.5,color=0
endfor
erase
plt,0.8+msk*1.e-5,realcont=2,/nocont,/nofill,xminor=1,yminor=1,lct=64,std_mi, std_ma, int=std_int,/noer, $
   title='1) STD ratio - TropFlux', subtitle='', small=[1,4,1],/rempl,/nocolorb, marge=marge
;
NN=n_elements(lat)
;
usersym, [-.5,.5,.5,-.5,-.5],[-.5,-.5,.5,.5,-.5],/fill
;
for n=0,NN-1 do begin
  x=lon(n)
  y=lat(n)
  c=std_trop(n)
  cmi=std_mi
  cma=std_ma
  dc=cma-cmi
  col=((10+244*(c-cmi)/dc) > 10) < 254
  plots, x,y,psym=8,symsize=1.5,color=col
endfor
;
usersym, [-.5,.5,.5,-.5,-.5],[-.5,-.5,.5,.5,-.5]
;
for n=0,NN-1 do begin
  x=lon(n)
  y=lat(n)
  c=std_trop(n)
;
  plots, x,y,psym=8,symsize=1.5,color=0
endfor
plt,0.8+msk*1.e-5,realcont=2,/nocont,/nofill,xminor=1,yminor=1,lct=64,std_mi, std_ma, int=std_int,/noer, $
   title='2) STD ratop - ERAI', subtitle='', small=[1,4,2],/rempl,/nocolorb, marge=marge
;
NN=n_elements(lat)
;
usersym, [-.5,.5,.5,-.5,-.5],[-.5,-.5,.5,.5,-.5],/fill
;
for n=0,NN-1 do begin
  x=lon(n)
  y=lat(n)
  c=std_era(n)
  cmi=std_mi
  cma=std_ma
  dc=cma-cmi
  col=((10+244*(c-cmi)/dc) > 10) < 254
  plots, x,y,psym=8,symsize=1.5,color=col
endfor
;
usersym, [-.5,.5,.5,-.5,-.5],[-.5,-.5,.5,.5,-.5]
;
for n=0,NN-1 do begin
  x=lon(n)
  y=lat(n)
  c=std_era(n)
;
  plots, x,y,psym=8,symsize=1.5,color=0
endfor
;
plt,0.8+msk*1.e-5,realcont=2,/nocont,/nofill,xminor=1,yminor=1,lct=64,std_mi, std_ma, int=std_int,/noer, $
   title='3) STD rato - OAFlux', subtitle='', small=[1,4,3],/rempl,/nocolorb, marge=marge
;
NN=n_elements(lat)
;
usersym, [-.5,.5,.5,-.5,-.5],[-.5,-.5,.5,.5,-.5],/fill
;
for n=0,NN-1 do begin
  x=lon(n)
  y=lat(n)
  c=std_oaflx(n)
  cmi=std_mi
  cma=std_ma
  dc=cma-cmi
  col=((10+244*(c-cmi)/dc) > 10) < 254
  plots, x,y,psym=8,symsize=1.5,color=col
endfor
;
usersym, [-.5,.5,.5,-.5,-.5],[-.5,-.5,.5,.5,-.5]
;
for n=0,NN-1 do begin
  x=lon(n)
  y=lat(n)
  c=std_oaflx(n)
;
  plots, x,y,psym=8,symsize=1.5,color=0
endfor
;
plt,0.8+msk*1.e-5,realcont=2,/nocont,/nofill,xminor=1,yminor=1,lct=64,std_mi, std_ma, int=std_int,/noer, $
   title='4) STD rato - SWR_olr', subtitle='', small=[1,4,4],/rempl, marge=marge1
;
NN=n_elements(lat)
;
usersym, [-.5,.5,.5,-.5,-.5],[-.5,-.5,.5,.5,-.5],/fill
;
for n=0,NN-1 do begin
  x=lon(n)
  y=lat(n)
  c=std_olr(n)
  cmi=std_mi
  cma=std_ma
  dc=cma-cmi
  col=((10+244*(c-cmi)/dc) > 10) < 254
  plots, x,y,psym=8,symsize=1.5,color=col
endfor
;
usersym, [-.5,.5,.5,-.5,-.5],[-.5,-.5,.5,.5,-.5]
;
for n=0,NN-1 do begin
  x=lon(n)
  y=lat(n)
  c=std_olr(n)
;
  plots, x,y,psym=8,symsize=1.5,color=0
endfor
;
closeps
;
end
